precision mediump float;			// Set the default precision to medium. We don't need as high of a precision in the fragment shader.
uniform lowp sampler2D u_Texture;	// The input texture.
uniform lowp sampler2D u_alpha;		// The alpha image
varying lowp vec4 v_Color;			// This is the color from the vertex shader interpolated across the triangle per fragment.
varying vec2 v_TexCoordinate;		// Interpolated texture coordinate per fragment.

//uses  https://github.com/jamieowen/glsl-blend/blob/master/source/PhotoshopMathFP.glsl

vec3 Desaturate(vec3 color, float Desaturation)
{
	vec3 grayXfer = vec3(0.3, 0.59, 0.11);
	vec3 gray = vec3(dot(grayXfer, color));
	return mix(color, gray, Desaturation);
}

#define BlendColorBurnf(base, blend) 	((blend == 0.0) ? blend : max((1.0 - ((1.0 - base) / blend)), 0.0))
#define Blend(base, blend, funcf) 		vec3(funcf(base.r, blend.r), funcf(base.g, blend.g), funcf(base.b, blend.b))
#define BlendColorBurn(base, blend) 	Blend(base, blend, BlendColorBurnf)

void main()
{
	lowp vec4 sample;
	sample.rgb = Desaturate(texture2D(u_Texture, v_TexCoordinate).rgb, 1.0);
	sample.a = texture2D(u_alpha, v_TexCoordinate).a;

	vec3 burnColor = vec3(0.96, 0.82, 0.32);

	gl_FragColor = vec4(BlendColorBurn(sample.rgb, burnColor), sample.a);

}
