// Star Nest by Pablo Roman Andrioli
// https://www.shadertoy.com/view/XlfGRj
// 3D kaliset fractal

// This content is under the MIT License.

#define iterations 17
#define formuparam 0.53

#define volsteps 20
#define stepsize 0.1

#define zoom   0.800
#define tile   0.850
#define speed  0.005 

#define brightness 0.0015
#define darkmatter 0.300
#define distfading 0.730
#define saturation 0.850

precision mediump float;
uniform float u_Time;
uniform vec3 u_Resolution;

uniform lowp sampler2D u_Texture;	// The input texture.
uniform lowp sampler2D u_alpha;		// The alpha image
varying lowp vec4 v_Color;			// This is the color from the vertex shader interpolated across the triangle per fragment.
varying vec2 v_TexCoordinate;		// Interpolated texture coordinate per fragment.

void main()
{
	//get coords and direction
	vec2 uv = gl_FragCoord.xy / u_Resolution.xy - .5;
	uv.y *= u_Resolution.y / u_Resolution.x;
	vec3 dir = vec3(uv * zoom, 1.);
	float time = u_Time * speed + .25;

	vec3 from=vec3(1.,.5,0.5);
	from+=vec3(time*2.,time,-2.);
	
	//volumetric rendering
	float s=0.1,fade=1.;
	vec3 v=vec3(0.);
	for (int r=0; r<volsteps; r++) {
		vec3 p=from+s*dir*.5;
		p = abs(vec3(tile)-mod(p,vec3(tile*2.))); // tiling fold
		float pa,a=pa=0.;
		for (int i=0; i<iterations; i++) { 
			p=abs(p)/dot(p,p)-formuparam; // the magic formula
			a+=abs(length(p)-pa); // absolute sum of average change
			pa=length(p);
		}
		float dm=max(0.,darkmatter-a*a*.001); //dark matter
		a*=a*a; // add contrast
		if (r>6) fade*=1.-dm; // dark matter, don't render near
		//v+=vec3(dm,dm*.5,0.);
		v+=fade;
		v+=vec3(s,s*s,s*s*s*s)*a*brightness*fade; // coloring based on distance
		fade*=distfading; // distance fading
		s+=stepsize;
	}
	v=mix(vec3(length(v)),v,saturation); //color adjust

	vec3 color = texture2D(u_Texture, v_TexCoordinate).rgb;
	float grey = 0.21 * color.r + 0.71 * color.g + 0.07 * color.b;
	float alpha = texture2D(u_alpha, v_TexCoordinate).a;
	gl_FragColor = vec4(v*0.01*grey*alpha, alpha);	
}
