precision mediump float;

uniform float u_Time;
uniform vec3 u_Resolution;

uniform lowp sampler2D u_Texture;	// The input texture.
uniform lowp sampler2D u_alpha;		// The alpha image
varying lowp vec4 v_Color;			// This is the color from the vertex shader interpolated across the triangle per fragment.
varying vec2 v_TexCoordinate;		// Interpolated texture coordinate per fragment.


#define FREQUENCY 90.
#define SPEED 0.05
#define TOP_COLOR vec3(1)
#define BOTTOM_COLOR vec3(1,0,0)

void main()
{
	vec2 p = gl_FragCoord.xy;
 	p /= u_Resolution.y;    
    float u = p.y*2.;
    
    p *= mat2(1,-1,1,1) / sqrt(2.);
    p.y += u_Time * SPEED;
    p = sin (p * FREQUENCY);
    
    u = pow( smoothstep(0., 1., u + p.x*p.y ), 64.);
    
	vec3 color = texture2D(u_Texture, v_TexCoordinate).rgb;
	float grey = 0.21 * color.r + 0.71 * color.g + 0.07 * color.b;
	float alpha = texture2D(u_alpha, v_TexCoordinate).a;
    gl_FragColor = vec4(mix(TOP_COLOR, BOTTOM_COLOR, u) * grey * alpha, alpha);
}